@@ -1,5 +1,5 @@
 from .base import ReadOnlyObjectItem, CRUDObjectItem, CRObjectItem
-from .mixin import PayURLMixin, RefundCaptureVoidObjectItemMixin, CardShareObjectItemMixin
+from .mixin import PayURLMixin, RefundCaptureVoidObjectItemMixin, CardShareObjectItemMixin, ChargeObjectItemMixin, StartPauseStopActiveObjectItemMixin
 
 
 class Product(CRUDObjectItem):
@@ -44,13 +44,20 @@ class Transaction(PayURLMixin, CRObjectItem):
     pass
 
 
-class Subscription(PayURLMixin, CRObjectItem):
+class Subscription(StartPauseStopActiveObjectItemMixin, PayURLMixin, CRObjectItem):
     """
     Subscription object
     """
     pass
 
 
+class Authorization(ChargeObjectItemMixin, PayURLMixin, CRObjectItem):
+    """
+    Authorization object
+    """
+    pass
+
+
 class Sale(RefundCaptureVoidObjectItemMixin, ReadOnlyObjectItem):
     """
     Sale object
